==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesChr.php <==
<?php
/** Cherokee (ᏣᎳᎩ)
 *
 * @addtogroup Language
 *
 * @author SPQRobin
 */

$messages = array(
'about'          => 'ᎬᏩᏚᏫᏛ',
'article'        => 'ᎤᏓᏡᎬ',
'qbpageinfo'     => 'ᎦᎷᎯᏍᏗ',
'qbspecialpages' => 'ᎤᏤᎵᏛ',
'navigation'     => 'ᎠᏂᎩᏍᏗ ᏥᏳ',

'help'             => 'ᎠᎵᏍᏕᎸᏗ',
'search'           => 'ᎠᏯᏍᏗ',
'go'               => 'ᎮᎦ',
'history'          => 'ᏆᏥ ᎧᏃᎮᏍᎩ',
'history_short'    => 'ᎧᏃᎮᏍᎩ',
'printableversion' => 'ᎦᎴᏯᏛ ᏅᎬᎪᏔᏅᎯ',
'permalink'        => 'ᏂᎪᎯᎸ ᏕᎬᏔᏛ',
'talkpagelinktext' => 'ᎧᏃᎮᎸᏗ',
'talk'             => 'ᎧᏃᎮᎸᏗ',
'toolbox'          => 'ᎪᎱᏍᏗ ᎬᏔᏂᏓᏍᏗ ᎧᏁᏌᎢ',
'otherlanguages'   => 'ᎭᏫᎾᏗᏢ ᏐᎢ ᏗᎦᏬᏂᎯᏍᏗ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutpage'     => 'Project:ᎬᏩᏚᏫᏛ',
'currentevents' => 'ᏗᏤᎢ',
'mainpage'      => 'ᎤᎵᎮᎵᏍᏗ',
'portal'        => 'ᎾᎥ ᏄᎾᏓᎸ ᎠᏍᏚᎢᏍᏗ',
'sitesupport'   => 'ᎠᎵᏍᎪᎸᏙᏗ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'ᎤᏓᏡᎬ',
'nstab-category' => 'ᏗᎦᎪᏗ',

# Search results
'powersearch' => 'ᎠᏯᏍᏗ',

# Preferences page
'searchresultshead' => 'ᎠᏯᏍᏗ',

# Recent changes
'recentchanges' => 'ᎾᏞᎬ ᏗᎦᏁᏟᏴᏍᏗ',

# Recent changes linked
'recentchangeslinked' => 'ᎪᎱᏍᏗ ᎠᎾᏓᏛᏂ ᏗᎦᏁᏟᏴᏍᏗ',

# Upload
'upload' => 'ᎦᎸᎳᏗᏢ ᎠᎧᎵᎢ ᎠᏝᎥᎢ',

# Image list
'ilsubmit' => 'ᎠᏯᏍᏗ',

# Random page
'randompage' => 'ᎤᏍᏆᏂᎪᏗ ᎤᏆᏓᏛ',

# Miscellaneous special pages
'specialpages' => 'ᎤᏤᎵᏛ ᏚᏆᏓᏛ',

# Delete/protect/revert
'actioncomplete' => 'ᎠᏍᏆᏙᏅᎯ',

# What links here
'whatlinkshere' => 'ᎦᏙ ᎤᏍᏗ ᏗᏕᎬᏔᏛ ᎠᎭᏂ',

# Block/unblock
'proxyblocksuccess' => 'ᎠᏍᏆᏛᎯ.',

);

==> mediawiki-1.13.5.tar.gz: mediawiki-1.13.5/languages/messages/MessagesChr.php <==
<?php
/** Cherokee (ᏣᎳᎩ)
 *
 * @ingroup Language
 * @file
 *
 * @author Maximillion Pegasus
 */

$messages = array(
# Dates
'january'  => 'UᏃᎸᏔᏂ',
'february' => 'KᎠᎦᎵ',
'march'    => 'ᎠᏄᏱ',
'april'    => 'ᏥᎶᏂ',
'june'     => 'DᎡᎭᎷᏱ',

'about'          => 'ᎬᏩᏚᏫᏛ',
'article'        => 'ᎤᏓᏡᎬ',
'qbpageinfo'     => 'ᎦᎷᎯᏍᏗ',
'qbspecialpages' => 'ᎤᏤᎵᏛ',
'navigation'     => 'ᎠᏂᎩᏍᏗ ᏥᏳ',

'help'             => 'ᎠᎵᏍᏕᎸᏗ',
'search'           => 'ᎠᏯᏍᏗ',
'go'               => 'ᎮᎦ',
'history'          => 'ᏆᏥ ᎧᏃᎮᏍᎩ',
'history_short'    => 'ᎧᏃᎮᏍᎩ',
'printableversion' => 'ᎦᎴᏯᏛ ᏅᎬᎪᏔᏅᎯ',
'permalink'        => 'ᏂᎪᎯᎸ ᏕᎬᏔᏛ',
'talkpagelinktext' => 'ᎧᏃᎮᎸᏗ',
'talk'             => 'ᎧᏃᎮᎸᏗ',
'toolbox'          => 'ᎪᎱᏍᏗ ᎬᏔᏂᏓᏍᏗ ᎧᏁᏌᎢ',
'otherlanguages'   => 'ᎭᏫᎾᏗᏢ ᏐᎢ ᏗᎦᏬᏂᎯᏍᏗ',
'jumptosearch'     => 'ᎡᏗt',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutpage'            => 'Project:ᎬᏩᏚᏫᏛ',
'currentevents'        => 'ᏗᏤᎢ',
'mainpage'             => 'ᎤᎵᎮᎵᏍᏗ',
'mainpage-description' => 'ᎤᎵᎮᎵᏍᏗ',
'portal'               => 'ᎾᎥ ᏄᎾᏓᎸ ᎠᏍᏚᎢᏍᏗ',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'ᎤᏓᏡᎬ',
'nstab-category' => 'ᏗᎦᎪᏗ',

# General errors
'viewsource' => 'DᎢᎧᏃᏗᎢ DᎢᏓᎴᎲᏍᎬ',

# Diffs
'editundo' => 'IᎬᎾᏕᏍᏗ',

# Search results
'powersearch' => 'ᎠᏯᏍᏗ',

# Preferences page
'searchresultshead' => 'ᎠᏯᏍᏗ',

# Recent changes
'recentchanges' => 'ᎾᏞᎬ ᏗᎦᏁᏟᏴᏍᏗ',

# Recent changes linked
'recentchangeslinked' => 'ᎪᎱᏍᏗ ᎠᎾᏓᏛᏂ ᏗᎦᏁᏟᏴᏍᏗ',

# Upload
'upload' => 'ᎦᎸᎳᏗᏢ ᎠᎧᎵᎢ ᎠᏝᎥᎢ',

# Random page
'randompage' => 'ᎤᏍᏆᏂᎪᏗ ᎤᏆᏓᏛ',

# Watchlist
'watch' => 'WᎠᏥ',

# Delete/protect/revert
'actioncomplete' => 'ᎠᏍᏆᏙᏅᎯ',

# What links here
'whatlinkshere' => 'ᎦᏙ ᎤᏍᏗ ᏗᏕᎬᏔᏛ ᎠᎭᏂ',

# Block/unblock
'proxyblocksuccess' => 'ᎠᏍᏆᏛᎯ.',

# Special:NewImages
'ilsubmit' => 'ᎠᏯᏍᏗ',

# Special:SpecialPages
'specialpages' => 'ᎤᏤᎵᏛ ᏚᏆᏓᏛ',

);
